//  Data Panel for SpXZeigR
// This works with SpXZeigR 4.0

#pragma rtGlobals=1
#pragma IgorVersion=6.0
#pragma version=4.00

#include "udFLStandardStructure", version = 1.04
#include "udFLStandardFunctions", version = 1.04

// data structures

Static STRUCTURE xzDataPanelStructure

	variable dpw				// panel width
	variable dph				// panel height

ENDSTRUCTURE

// initialize data panel width and height

Static Function xzDataPanelInit(xzDPS)
	STRUCT xzDataPanelStructure &xzDPS
	
	xzDPS.dpw = 235
	xzDPS.dph = 330
	
	return 0
end

// Data Panel

Function xzDataPanelShow(restart)
	variable restart
	
	// kill or bring forward panel
	
	if (strlen(WinList("xzDataPanel","","WIN:64"))!=0)
		if (restart)
			KillWindow xzDataPanel
		else
			DoWindow/F xzDataPanel
			return 0
		endif
	endif
	
	// (re)initialize globals 

	SVAR dff = root:Packages:SpXZeigR:DataPanelParams:displayfromfolder
	SVAR dwc = root:Packages:SpXZeigR:DataPanelParams:displaywildcard
	
	dff = "root"
	dwc = ""
	
	// initialize new panel and screen sizes
	
	STRUCT xzDataPanelStructure xzDPS
	xzDataPanelInit(xzDPS)

	NVAR scrw = root:Packages:SpXZeigR:Globals:scrw
	NVAR scrh = root:Packages:SpXZeigR:Globals:scrh
	
	variable pleft, ptop, pwidth, pheight
	pleft = xzWWidth_G*scrw
	ptop = xzWTopOffset_G*scrh
	pwidth = pleft+xzDPS.dpw
	pheight = ptop+xzDPS.dph

	NewPanel/K=1/N=xzDataPanel/W=(pleft,ptop,pwidth,pheight) as "Data"
	ModifyPanel fixedSize=1, noEdit=1

	// Tabs
	
	TabControl tb, pos={1,2},size={xzDPS.dpw,20}, proc=xz_tcShowDataTab
	TabControl tb, tabLabel(0)=xzpan00a, value=0
	TabControl tb, tabLabel(1)=xzpan00b, value=1
	
	// Controls
	
	xzDataPanelBuildTab(0)
	xzDataPanelBuildTab(1)
	xzDataPanelBuildTab(99)
	
	// finalize new panel
	
	xzDataPanelFillTab(1)

End

// build a tab on the data panel

Static Function xzDataPanelBuildTab(tab)
	variable tab
	
	STRUCT udFLStandardStructure udFL
	udFLZeroStructure(udFL)

	// Control Globals and Mode Settings

	// display tab
	
	SVAR dff = root:Packages:SpXZeigR:DataPanelParams:displayfromfolder
	SVAR dwc = root:Packages:SpXZeigR:DataPanelParams:displaywildcard

	SVAR idpm = root:Packages:SpXZeigR:DataPanelParams:initialDataPanelMode
	
	// load tab
	
	SVAR ltf = root:Packages:SpXZeigR:DataPanelParams:loadtofolder
	SVAR lfp = root:Packages:SpXZeigR:DataPanelParams:loadfileprefix
	SVAR uD = root:Packages:SpXZeigR:DataPanelParams:userData
	SVAR lFN = root:Packages:SpXZeigR:DataPanelParams:loadfunctionname
	
	string dfSpectrumType, dfGraphMode

	variable dfSTn, dfGMn, dfdffn

	// build a specific tab
	
	switch(tab)
	
		case 0:
	
			lfN = StringFromList(0,udFLLoaderList(1))
		
			// Load Tab
			// =====
		
			// Folder List
			
			PopupMenu flist_tb0,pos={20,39},size={122,20},title=xzpan00e,fSize=12
			dfdffn = WhichListItem(dff,xzFolderList(tab))+1
			PopupMenu flist_tb0, mode=dfdffn,popvalue=dff, value=#"xzFolderList(0)"
			PopupMenu flist_tb0, proc=xz_popCreateNewFolderName
		
			// CreateNew Input
		
			SetVariable newdir_tb0,pos={20,65},size={180,17},title="root:",fSize=12
			SetVariable newdir_tb0,value=ltf, proc=xz_svcValidateNewLoadFolderName
			SetVariable newdir_tb0, help={"You may NOT use : or space characters here!"}
		
			// FileName
		
			PopupMenu fname_tb0,pos={20,92},size={87,20},title=xzpan00n,fSize=12
			PopupMenu fname_tb0,mode=1,value=#"xzRenameInputList()"
			PopupMenu fname_tb0, proc=xz_popCreateNewTraceName

			// CreateNew Filename
		
			SetVariable newfname_tb0,pos={20,118},size={180,17},title="prefix:",fSize=12
			SetVariable newfname_tb0,value=lfp, proc=xz_svcValidateNewTraceName
			SetVariable newfname_tb0, help={"You may NOT use certain characters here!"}

			// Loader
		
			PopupMenu loader_tb0,pos={20,148},size={87,20},title=xzpan00l,fSize=12
			PopupMenu loader_tb0,mode=1,value=#"udFLLoaderList(0)"
			PopupMenu loader_tb0, proc=xz_popChangeLoaderModes
	
			// Processing Modes
			
			PopupMenu lmode_tb0,pos={20,175},size={87,20},title=xzpan00p,fSize=12
			PopupMenu lmode_tb0, mode=1, value=#"xzFileLoaderModeList()"

			// User Data
			
			SetVariable userData_tb0,pos={20,200},size={200,17},title="User Data:",fSize=12
			SetVariable userData_tb0,value=uD

			// Report Modes
			
			PopupMenu rpmode_tb0,pos={20,223},size={87,20},title=xzpan00q,fSize=12
			PopupMenu rpmode_tb0, mode=2, value="Silent;Normal;Verbose;"

//			Button showfil_tb0,pos={190,300},size={20,20}, title="v", proc=xz_bcReshowFileList
//			Button showfil_tb0, font="Geneva",fSize=10, fColor=(49151,49151,65535)

			// Mulit-Dir
		
//			CheckBox multidir_tb0,pos={20,180},size={87,20},title=xzpan00m
//			CheckBox multidir_tb0,value=0, proc=xz_cbcSetMultiDir
			
			// SetPaths
			
			Button setpaths_tb0,pos={20,250},size={50,55}, proc=xz_bcSetDirPaths
			Button setpaths_tb0, font="Geneva",fSize=12, fColor=(49151,49151,65535)
			
			PathInfo xzDataFiles
			if (V_flag==0)
				Button setpaths_tb0, title="Set\rDir\rPath"
			else
				Button setpaths_tb0, title="Reset\rDir\rPath"
			endif
			break
		
		case 1:
			
			dfSpectrumType = StringByKey("spectrumtype",idpm,"=")
			dfGraphMode = StringByKey("graphmode",idpm,"=")
			
			dfSTn = WhichListItem(dfSpectrumType,xzSpectrumTypesList())+1
			dfGMn =  WhichListItem(dfGraphMode,xzGraphModesList())+1

			// Display Tab
			// =====
		
			// Folder List
			
			PopupMenu flist_tb1,pos={20,39},size={122,20},title=xzpan00f,fSize=12
			dfdffn = WhichListItem(dff,xzFolderList(tab))+1
			PopupMenu flist_tb1, mode=dfdffn,popvalue=dff, value=#"xzFolderList(1)", proc=xz_popChangeDisplayFromFolder
		
			// File List
		
			PopupMenu spectrum_tb1,pos={20,65},size={87,20},title=xzpan00g,fSize=12
			dfdffn = WhichListItem(dff,xzFolderList(tab))+1
			PopupMenu spectrum_tb1,mode=1,value=#"xzSpectraList(0)", proc=xz_popSelectDisplayTraces
			
			// Wave Note
			
			Button wavenote_tb1, pos={200,65}, size={20,20}, title="?", fSize=10, proc=xz_bcShowWaveNote
			
			// Wildcard Input
		
			SetVariable wildcard_tb1,pos={20,92},size={185,17},title=xzpan00h,fSize=12
			SetVariable wildcard_tb1,value=dwc, proc=xz_svcValidateWildCard
		
			// Multitrace Control
		
			PopupMenu multitrace_tb1,pos={20,120},size={157,20},title=xzpan00i,fSize=12
			PopupMenu multitrace_tb1,mode=1,popvalue="All on New",value= #"xzMultiTraceMenu()"
		
			// Spectrum Type
			
			PopupMenu type_tb1,pos={20,190},size={142,20},title=xzpan00j,fSize=12
			PopupMenu type_tb1,mode=dfSTn,value=#"xzSpectrumTypesList()", popValue=dfSpectrumType
		
			// Plotmode
			
			PopupMenu plotmode_tb1,pos={20,220},size={108,20},title=xzpan00k,fSize=12
			PopupMenu plotmode_tb1,mode=dfGMn,value=#"xzGraphModesList()", popValue=dfGraphMode
	
			CheckBox xloader_tb1,pos={20,165},size={87,20},title=xzpan00o
			CheckBox xloader_tb1,value=0, proc=xz_cbcCheckLoaderParams
		
		default:

			// Close Panel When Complete
		
			CheckBox closeme,pos={34,310},size={139,14},title=xzpan00d
			CheckBox closeme,value= 0
			
			// Do It!
			
			Button doit,pos={124,260},size={70,20},proc=xz_bcDoIt
			Button doit, font="Geneva",fSize=14, fColor=(49151,49151,65535)

			Button doboth,pos={84,285},size={140,20},title=xzpan00c, disable=1, proc=xz_bcDoBoth
			Button doboth, font="Geneva",fSize=14, fColor=(49151,49151,65535)
	
	endswitch
	
	return 0
	
End

// fill a tab when it is selected

Function xzDataPanelFillTab(tab)
	variable tab
	
	// blanket on/off of tab controls
	
	ModifyControlList ControlNameList("",";","*_tb0") disable=(tab!=0)
	ModifyControlList ControlNameList("",";","*_tb1") disable=(tab!=1)
			
	// disable select controls on given tab
	
	switch(tab)
		case 0:
			Button doit, title=xzpan00a, userData="Load"
			ControlInfo flist_tb0
			SetVariable newdir_tb0 disable=(cmpstr(S_value,"Create New")!=0)
			ControlInfo fname_tb0
			SetVariable newfname_tb0 disable=(V_Value!=4)
			ControlInfo flist_tb1
			break
		case 1:
			Button doit, title=xzpan00b, userData="Display"
			ControlInfo flist_tb1
			if (V_value<3)
				PopupMenu spectrum_tb1 disable = 1
				PopupMenu multitrace_tb1 disable = 0
				SetVariable wildcard_tb1 disable = 1
				Button doit disable = 1
				CheckBox xloader_tb1 disable=0
				Button wavenote_tb1 disable=1
			else
				ControlInfo spectrum_tb1
				Button wavenote_tb1 disable=(V_value<3)
				SetVariable wildcard_tb1 disable=(V_value!=2)
				PopupMenu multitrace_tb1 disable=((V_value>2)||(cmpstr(S_value,"(no spectra)")==0))
				CheckBox xloader_tb1 disable=1
			endif
			break
	endswitch

	// show the subpanel as appropriate
	
	xzSubPanelShow(tab)
	
	return 0

End

// show or kill the file list panel

Function xzSubPanelShow(tab)
	variable tab
	
	wave/T flist = root:Packages:SpXZeigR:DataPanelParams:filesindatapath
	wave slist =root:Packages:SpXZeigR:DataPanelParams:nfilesindatapath
	
	string lfname=""
		
	if (tab==1)
	
		// switch from load to display
		
		if (strlen(ChildWindowList("#"))!=0)
			KillWindow #xzFileListPanel
		endif
	else
	
		// switch from display to load
		
		PathInfo xzDataFiles
		if (V_flag)
			ControlInfo loader_tb0
			lfname = StringFromList(V_value-1,udFLLoaderList(1))
			xzGetFilesInDataDirPath(lfname)
			if (strlen(ChildWindowList("#"))==0)
				NewPanel/EXT=2/K=2/N=xzFileListPanel/HOST=#/W=(.2,0,0,0.25) as "File List"
				ListBox theList,pos={4,4},size={225,235}, mode=4, listwave=flist, selWave=slist
				SetActiveSubWindow ##
			endif
		else
			if (strlen(ChildWindowList("#"))!=0)
				KillWindow #xzFileListPanel
			endif
		endif
	endif
	
	return 0
end

// CONTROLS

// Tabs

// show a tab when it is clicked

Function xz_tcShowDataTab(TC)
	STRUCT WMTabControlAction &TC
	
	switch(TC.eventcode)
		case 2:
			xzDataPanelFillTab(TC.tab)
			break
	endswitch
	
End

// Buttons

// show wave note

Function xz_bcShowWaveNote(bc) : ButtonControl
	STRUCT WMButtonAction &bc

	// set notebook size
		
	NVAR scrw = root:Packages:SpXZeigR:Globals:scrw
	NVAR scrh = root:Packages:SpXZeigR:Globals:scrh
	
	variable pleft, ptop, pwidth, pheight
	
	string wnote, wname, fname, wnotem

	wnotem = "Wave Note for "
	
	switch(bc.eventCode)
		case 2:
			ControlInfo flist_tb1
			if (cmpstr(S_value,"root")==0)
				fname = "root:"
			else
				fname = "root:" + S_value + ":"
			endif
			wnotem += fname
			ControlInfo spectrum_tb1
			wname = fname + S_value
			wnote = note($wname)
			if (strlen(wnote)==0)
				wnote = "NO NOTES EXIST FOR THIS DATA"
			endif
			
			// kill prior notebook
			
			if (strlen(WinList("xzWaveNote","","WIN:16"))!=0)
				KillWindow xzWaveNote
			endif
			
			pleft = 0.5*xzWWidth_G*scrw
			ptop = xzWTopOffset_G*scrh
			pwidth = pleft+320
			pheight = ptop+200
			
			NewNoteBook/F=0/K=1/N=xzWaveNote/W=(pleft,ptop,pwidth,pheight)
			Notebook xzWaveNote status={wnotem,0}
			Notebook xzWaveNote text=wnote	
			
			break
	endswitch
	
	return 0
end

// set paths

Function xz_bcSetDirPaths(bc) : ButtonControl
	STRUCT WMButtonAction &bc
	
	switch(bc.eventCode)
		case 2:
			NewPath/O/M=xzstr03a xzDataFiles
			if (V_flag!=0)
				return 0
			endif
			Button setpaths_tb0, title="Reset\rDir\rPath"
			xzSubPanelShow(0)
			break
	endswitch
	
	return 0
end

// load and display data

Function xz_bcDoBoth(ba) : ButtonControl
	STRUCT WMButtonAction &ba

	SVAR llowl = root:Packages:SpXZeigR:DataPanelParams:loadlistofwavesloaded
	
	variable cm
	
	switch(ba.eventCode)
		case 2:
			ControlInfo closeme
			cm = V_value
			CheckBox closeme value=0
			ba.UserData="Load"
			xz_bcDoIt(ba)
			if (strlen(llowl)==0)
				DoAlert 0, xzStr07
				break
			endif
			CheckBox closeme value=cm
			ba.UserData="Display"
			xz_bcDoIt(ba)			
	endswitch
	return 0
end

// load or display data

Function xz_bcDoIt(ba) : ButtonControl
	STRUCT WMButtonAction &ba

	SVAR dff = root:Packages:SpXZeigR:DataPanelParams:displayfromfolder
	SVAR llowl = root:Packages:SpXZeigR:DataPanelParams:loadlistofwavesloaded
	SVAR dwl = root:Packages:SpXZeigR:DataPanelParams:displaywavelist
	SVAR dwc = root:Packages:SpXZeigR:DataPanelParams:displaywildcard
	SVAR lfn = root:Packages:SpXZeigR:DataPanelParams:loadfunctionname
	NVAR spt = root:Packages:SpXZeigR:GraphParams:spectrumtype
	NVAR grm = root:Packages:SpXZeigR:GraphParams:graphmode
	
	NVAR lnu = root:Packages:SpXZeigR:DataPanelParams:loadnameusing
	NVAR dmt = root:Packages:SpXZeigR:DataPanelParams:displaymultitrace
	
	variable cm
	
	switch( ba.eventCode )
		case 2:
		
			ControlInfo closeme
			cm = V_Value
					
			strswitch(ba.UserData)
			
				// load
				
				case "Load":
					ControlInfo fname_tb0
					lnu = V_value
					ControlInfo loader_tb0
					lfn = StringFromList(V_value-1,udFLLoaderList(1),";")
					llowl = ""
					xzLoadData()
					break
					
				// display
				
				case "Display":
					ControlInfo spectrum_tb1
					if ((cmpstr(S_Value,"(no spectra)")==0)&&(strlen(llowl)==0))
						DoAlert 0, xzstr02
						return 0
					endif
					strswitch(S_Value)
						case "All":
							dwl = xzSpectraList(1)
							break
						case "Match WildCard":
							dwl = ListMatch(xzSpectraList(1),dwc)
							if ((strlen(dwl)==0)&&(strlen(llowl)==0))
								DoAlert 0, xzstr02
								return 0
							endif
							break
						default:
							dwl = S_Value				
					endswitch
					
					ControlInfo type_tb1
					spt = V_value
					ControlInfo plotmode_tb1
					grm = V_value
					ControlInfo multitrace_tb1
					dmt = V_Value
					if (strlen(llowl)!=0)
						dwl = llowl				
					endif
					xzDisplayData()					
					break
			endswitch
			if (cm==1)
				DoWindow/K xzDataPanel
			endif
	endswitch

	return 0
End

// Set Variables

// validate wild card

Function xz_svcValidateWildCard(sv) : SetVariableControl
	STRUCT WMSetVariableAction &sv

	SVAR dwc = root:Packages:SpXZeigR:DataPanelParams:displaywildcard
	
	variable trn
	
	switch(sv.eventCode)
		case 2:
			if ((strsearch(sv.sval,":",0)>0)||(strsearch(sv.sval," ",0)>0))
				dwc = "INVALID : or Spaces!"
				ControlUpdate wildcard_tb1
				trn = ticks
				do
				while((ticks-trn)<90)
				dwc=""
				SetVariable wildcard_tb1 activate
			endif
			break	
	endswitch
	
End

// validate new folder string

Function xz_svcValidateNewLoadFolderName(sv) : SetVariableControl
	STRUCT WMSetVariableAction &sv

	SVAR lff = root:Packages:SpXZeigR:DataPanelParams:loadtofolder
	
	variable trn
	
	switch(sv.eventCode)
		case 2:
			if (strsearch(sv.sval," ",0)>0)
				lff = "INVALID Spaces!"
				ControlUpdate newdir_tb0
				trn = ticks
				do
				while((ticks-trn)<90)
				lff=""
				SetVariable newdir_tb0 activate
			endif
			break	
	endswitch
	
	return 0
	
End

// validate new file string

Function xz_svcValidateNewTraceName(sv) : SetVariableControl
	STRUCT WMSetVariableAction &sv

	SVAR lfp = root:Packages:SpXZeigR:DataPanelParams:loadfileprefix
	
	switch(sv.eventCode)
		case 2:
			lfp = CleanupName(lfp,0)
			SetVariable newfname_tb0 activate
			break	
	endswitch
	
	return 0
End

// Checkboxes

// set multi-directory loading

Function xz_cbcSetMultiDir(cb) : CheckBoxControl
	STRUCT WMCheckBoxAction &cb
	
	switch(cb.eventCode)
		case 2:
			Button setpaths_tb0 disable=(cb.checked)
			break	
	endswitch
	
	return 0
End

// validate new folder string

Function xz_cbcCheckLoaderParams(cb) : CheckBoxControl
	STRUCT WMCheckBoxAction &cb
	
	switch(cb.eventCode)
		case 2:
			PopupMenu type_tb1 disable=(cb.checked)
			break	
	endswitch
	
	return 0
End

// PopupMenu

// change loader modes (and zero the userData) when loader is changed

Function xz_popChangeLoaderModes(pa) : PopupMenuControl
	STRUCT WMPopupAction &pa

	SVAR uD = root:Packages:SpXZeigR:DataPanelParams:userData
	SVAR lFN = root:Packages:SpXZeigR:DataPanelParams:loadfunctionname
	
	string lFNa
	
	switch(pa.eventCode)
		case 2:
			lFNa = "udStFiLr" + pa.popStr		
			if (cmpstr(lFNa,lfN)==0)
				return 0
			endif
			uD = ""
			lFN = lfNa		
			PopupMenu lmode_tb0,mode=1,value=#"xzFileLoaderModeList()"
			if (strlen(ChildWindowList("#"))!=0)
				xzGetFilesInDataDirPath(lFNa)
			endif
	endswitch
	
	return 0
End

// potentially create a new directory name

Function xz_popCreateNewFolderName(pa) : PopupMenuControl
	STRUCT WMPopupAction &pa

	SVAR ltf = root:Packages:SpXZeigR:DataPanelParams:loadtofolder
	
	switch(pa.eventCode)
		case 2:
			SetVariable newdir_tb0 disable=(pa.popNum!=1)
			if (pa.popNum < 3)
				PopupMenu flist_tb0 mode=1
				SetVariable newdir_tb0 disable=0
				ltf = ""
			else
				ltf = pa.popStr
			endif
	endswitch
	
	return 0
End

// potentially create a new trace name

Function xz_popCreateNewTraceName(pa) : PopupMenuControl
	STRUCT WMPopupAction &pa
	
	switch(pa.eventCode)
		case 2:
			SetVariable newfname_tb0 disable=(pa.popNum!=4)
	endswitch
	
	return 0
End

// change things when display folder is changed

Function xz_popChangeDisplayFromFolder(pa) : PopupMenuControl
	STRUCT WMPopupAction &pa

	SVAR dff = root:Packages:SpXZeigR:DataPanelParams:displayfromfolder
	SVAR lff = root:Packages:SpXZeigR:DataPanelParams:loadtofolder
	
	switch( pa.eventCode )
		case 2:
		
			// display from load
			
			if (pa.popNum < 3)
				PopupMenu flist_tb1 mode = 1
				PopupMenu spectrum_tb1 disable=1
				PopupMenu multitrace_tb1 disable=0
				Button doit disable=1
				Button doboth disable=0
				CheckBox xloader_tb1 disable=0
				Button wavenote_tb1 disable=1
				dff = "root"
				break
			endif
			dff = pa.popStr
			PopupMenu spectrum_tb1 mode=1, disable=0
			ControlInfo spectrum_tb1
			PopupMenu multitrace_tb1 disable=(cmpstr(S_value,"All")!=0)
			SetVariable wildcard_tb1 disable=(cmpstr(S_value,"Match WildCard")!=0)
			Button wavenote_tb1 disable=(V_value<2)
			Button doit disable=0
			Button doboth disable=1
			CheckBox xloader_tb1 disable=1
			PopupMenu type_tb1 disable=0
			CheckBox xloader_tb1 value=0
			break
	endswitch

	return 0
End

// change things when file list is changed

Function xz_popSelectDisplayTraces(pa) : PopupMenuControl
	STRUCT WMPopupAction &pa
	
	SVAR dff = root:Packages:SpXZeigR:DataPanelParams:displayfromfolder
	SVAR swn = root:Packages:SpXZeigR:DataPanelParams:selectedwavenote
	
	string wname = "root:"
		
	switch( pa.eventCode )
		case 2:
			swn = ""
			Button wavenote_tb1 disable=1
			switch(pa.popNum)
				case 1:
					PopupMenu multitrace_tb1 disable=(cmpstr(pa.popStr,"All")!=0)	
					SetVariable wildcard_tb1 disable=1
					break
				case 2:
					SetVariable wildcard_tb1 disable=0	
					PopupMenu multitrace_tb1 disable=0
					break
				case 3:
					PopupMenu spectrum_tb1 mode=1
					PopupMenu multitrace_tb1 disable=0	
					SetVariable wildcard_tb1 disable=1
					break
				default:
					SetVariable wildcard_tb1 disable=1
					PopupMenu multitrace_tb1 disable=1
					Button wavenote_tb1 disable=0
					if (cmpstr(dff,"root")==0)
						wname += pa.popStr
					else
						wname += dff + ":" + pa.popStr
					endif
					swn = note($wname)
			endswitch
			break
	endswitch

	return 0
End
