// Preferences for SpXZeigR
// This works with SpXZeigR 4.0
// date: 20.July.07
// please make a copy of this file before making any changes

#pragma rtGlobals=1
#pragma IgorVersion=6.0
#pragma version=4.00

// set the value of xzverbose to 0 to stop some of the printing from SpXZeigR to the history window
// the commands xzSilent(1) and xzSilent(0) toggle it off and on

Constant xzverbose = 1

// Define any standard paths for data and storage
// This will avoid the prompt for these paths at StartUp
// Use Igor Pro conventions ...
// example: xzdatafilespath = "MyVolume:MyDocuments:IgorProData:"

StrConstant xzdatafilespath = ""
StrConstant xzstoragefilespath = ""

// The values below set the area of the screen to use for a new graph window
// Values are given as fraction of the screen size (width and height)
// The Graph windows will be tiled down the screen
// The History Window will be 5% from the screen bottom
// and will occupy 10 % of the screen height initially
// The Macintosh Menu bar occupies a portion of xzWTopOffset
// NOTE: Graph windows will extend past the right edge of the screen if
// xzWLeftOffset_G + xzWWidth_G > 1 (same applies for bottom edge)

Constant xzWLeftOffset_G = 0.01
Constant xzWTopOffset_G = 0.05
Constant xzWWidth_G = 0.7
Constant xzWHeight_G = 0.7

// Set the default font and font sizes for the graphs

StrConstant xzDefaultGraphFont ="Helvetica"
StrConstant xzDefaultGraphUnitEnvelope = "[]"
Constant xzDefaultAxesLabelSize = 14
Constant xzDefaultGraphTitleSize = 16
Constant xzDefaultAnnotationSize = 14

// Set the default labels and titles for various spectroscopies
// this function is called during initialization

Function xzInitSpectrumTypes()

	string/G GENERIC 
	GENERIC = "title=Generic;"
	GENERIC +="ylabel=Y Values;yunits=;yscaling=normal;"
	GENERIC += "xlabel=X Values;xunits=;xscaling=normal;"
	string/G AES 
	AES = "title=Auger;"
	AES +="ylabel=Intensity;yunits=counts/second;yscaling=normal;"
	AES += "xlabel=Kinetic Energy;xunits=eV;xscaling=normal;"
	string/G FTIR 
	FTIR = "title=Infrared;"
	FTIR +="ylabel=Absorbance;yunits=Arbitrary Units;yscaling=normal;"
	FTIR += "xlabel=Wavenumber;xunits=cm\S-1;xscaling=normal;"
	string/G XPS 
	XPS = "title=XPS;"
	XPS +="ylabel=Intensity;yunits=counts/second;yscaling=normal;"
	XPS += "xlabel=Binding Energy;xunits=eV;xscaling=reversed;"

End

// Set the various graph modes
// this function is called during initialization

Function xzInitGraphModes()

	string/G Draft
	Draft = "autoscale=on;showtitle=FALSE;tracemode=lines;tagtraces=TRUE;"
	string/G Proof
	Proof = "autoscale=off;showtitle=TRUE;tracemode=lines;tagtraces=FALSE;"
	string/G Publish
	Publish = "autoscale=nice;showtitle=TRUE;tracemode=dots;tagtraces=FALSE;"

End

// Set the defaults on the data panel
// this function is called during initialization

Function xzInitDataPanelMode()

	SVAR initialDataPanelMode
	
	initialDataPanelMode = "spectrumtype=XPS;"
	initialDataPanelMode += "graphmode=Draft;"

End
